# 共享出行-商家后台 记录文档

>## 开发须知
本项目是使用vue-admin-template基础模板开发，它基于 vue 和 element-ui实现，项目继承element-ui的组件，可以使用这些组件快速开发后台功能。
有关element组件api的使用，可以参考 [https://element.eleme.cn/#/zh-CN/component/installation](https://element.eleme.cn/#/zh-CN/component/installation)

## 配置信息
```
// 代理配置
- config/index.js
proxyTable: {
    '/api': {
        target: 'https://test.com',  // 可以切换成自己想连接的服务器
        changeOrigin: true,
        pathRewrite: {
            '^/api': '/'
        }
    }
}
// 打包配置
- config/dev.env.js (开发环境)
module.exports = merge(prodEnv, {
    NODE_ENV: '"development"',
    BASE_API: '"/api"'              // 配合代理配置，必须和proxyTable一致
})
- config/prod.env.js (生成环境)
module.exports = {
  NODE_ENV: '"production"',
  BASE_API: '"https://formal.com"', // 打包的服务器地址
}
// 请求配置
- utils/request.js
const service = axios.create({
    baseURL: process.env.BASE_API + '/iznaer-sbike-customer/', // api 的 base_url
    timeout: 10000, // 请求超时时间
    headers: { 'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8' }
})
// 将配置的BASE_API放进axios实例里初始化
```

## 项目启动
```
# 进入项目目录
cd ./share-customer-admin

# 安装依赖
npm install

# 启动服务
npm run dev
```

## 目录结构
```
├── build                       # 打包构建相关
├── config                      # vue-cli配置
├── src                         # 源代码                              
│   ├── api                     # 所有请求API
│   ├── assets                  # 主题 字体等静态资源
│   ├── components              # 全局公用组件
│   ├── directive               # 全局指令
│   ├── icons                   # 项目所用svg icons
│   ├── router                  # 路由
│   ├── store                   # 全局 store管理
│   ├── styles                  # 全局样式
│   ├── utils                   # 全局公用方法
│   ├── vendor                  # 公用vendor
│   ├── views                   # views 所有页面
│   │   ├── bike                # 车辆模块
│   │   │   ├── bikeList        # 车辆-车辆列表
│   │   │   ├── bikeMap         # 车辆-车辆分布
│   │   ├── capital             # 资金管理模块
│   │   │   ├── deposit         # 资金管理-押金管理
│   │   │   ├── gains           # 资金管理-收益管理
│   │   ├── home                # 首页模块
│   │   ├── layout              # 全局layout模块
│   │   ├── login               # 登录模块
│   │   ├── member              # 用户管理模块
│   │   │   ├── account         # 用户管理-钱包管理
│   │   │   ├── userInfo        # 用户管理-用户列表
│   │   ├── order               # 订单管理模块
│   │   │   ├── order           # 订单管理-订单列表
│   │   │   ├── locus           # 订单管理-订单轨迹
│   │   ├── parameter           # 参数设置模块
│   │   │   ├── base            # 参数设置-基础参数
│   │   │   ├── develop         # 参数设置-开发参数
│   │   │   ├── pay             # 参数设置-支付参数
│   │   ├── people              # 人员设置模块
│   │   │   ├── ground          # 人员设置-地勤人员
│   │   │   ├── manager         # 人员设置-管理员
│   │   ├── power               # 权限设置模块
│   │   │   ├── permissicon     # 权限设置-权限管理
│   │   │   ├── roles           # 权限设置-角色管理
│   │   ├── region              # 区域设置模块
│   │   ├── repair              # 报修管理模块
│   │   ├── 404.vue             # 404页面
│   ├── App.vue                 # 入口页面
│   ├── main.js                 # 入口文件 加载组件 初始化等 
│   ├── permission.js           # 权限管理
├── .babelrc                    # babel-loader 配置
├── .eslintrc.js                # eslint 配置项
├── .travis.yml                 # 自动化CI配置
├── .gitignore                  # git 忽略项
├── .postcss.js                 # postcss 配置
├── .editorconfig               # 编辑器配置
├── .eslintignore               # eslint 忽略项
├── index.html                  # html模板
├── favicon.ico                 # favicon图标
├── package.json                # package.json                 
```
