/**
 * Created by jiachenpan on 16/11/18.
 */

export function parseTime(time, cFormat) {
    if (arguments.length === 0) {
        return null
    }
    const format = cFormat || '{y}-{m}-{d} {h}:{i}:{s}'
    let date
    if (typeof time === 'object') {
        date = time
    } else {
        if (('' + time).length === 10) time = parseInt(time) * 1000
        date = new Date(time)
    }
    const formatObj = {
        y: date.getFullYear(),
        m: date.getMonth() + 1,
        d: date.getDate(),
        h: date.getHours(),
        i: date.getMinutes(),
        s: date.getSeconds(),
        a: date.getDay()
    }
    const time_str = format.replace(/{(y|m|d|h|i|s|a)+}/g, (result, key) => {
        let value = formatObj[key]
        // Note: getDay() returns 0 on Sunday
        if (key === 'a') { return ['日', '一', '二', '三', '四', '五', '六'][value ] }
        if (result.length > 0 && value < 10) {
            value = '0' + value
        }
        return value || 0
    })
    return time_str
}

export function formatTime(time, option) {
    time = +time * 1000
    const d = new Date(time)
    const now = Date.now()

    const diff = (now - d) / 1000

    if (diff < 30) {
        return '刚刚'
    } else if (diff < 3600) {
    // less 1 hour
        return Math.ceil(diff / 60) + '分钟前'
    } else if (diff < 3600 * 24) {
        return Math.ceil(diff / 3600) + '小时前'
    } else if (diff < 3600 * 24 * 2) {
        return '1天前'
    }
    if (option) {
        return parseTime(time, option)
    } else {
        return (
            d.getMonth() +
      1 +
      '月' +
      d.getDate() +
      '日' +
      d.getHours() +
      '时' +
      d.getMinutes() +
      '分'
        )
    }
}

export function formatDate(timeStamp) {
    const date = new Date(timeStamp)
    const y = date.getFullYear()
    let m = date.getMonth() + 1
    let d = date.getDate()
    m = m < 10 ? ('0' + m) : m
    d = d < 10 ? ('0' + d) : d
    return `${y}-${m}-${d}`
}

export function formatDateTime(timeStamp) {
    const date = new Date(timeStamp)
    const y = date.getFullYear()
    let m = date.getMonth() + 1
    let d = date.getDate()
    m = m < 10 ? ('0' + m) : m
    d = d < 10 ? ('0' + d) : d
    let hh = date.getHours()
    let mm = date.getSeconds()
    let ss = date.getMinutes()
    hh = hh < 10 ? ('0' + hh) : hh
    mm = mm < 10 ? ('0' + mm) : mm
    ss = ss < 10 ? ('0' + ss) : ss
    return `${y}-${m}-${d} ${hh}:${mm}:${ss}`
}

export function debounce(func, wait, immediate) {
    let timeout, args, context, timestamp, result

    const later = function() {
    // 据上一次触发时间间隔
        const last = +new Date() - timestamp

        // 上次被包装函数被调用时间间隔last小于设定时间间隔wait
        if (last < wait && last > 0) {
            timeout = setTimeout(later, wait - last)
        } else {
            timeout = null
            // 如果设定为immediate===true，因为开始边界已经调用过了此处无需调用
            if (!immediate) {
                result = func.apply(context, args)
                if (!timeout) context = args = null
            }
        }
    }

    return function(...args) {
        context = this
        timestamp = +new Date()
        const callNow = immediate && !timeout
        // 如果延时不存在，重新设定延时
        if (!timeout) timeout = setTimeout(later, wait)
        if (callNow) {
            result = func.apply(context, args)
            context = args = null
        }

        return result
    }
}

// 火星坐标 转换到 百度地图坐标
export function bd_encrypt(gg_lon, gg_lat) {
    var X_PI = Math.PI * 3000.0 / 180.0
    var x = gg_lon, y = gg_lat
    var z = Math.sqrt(x * x + y * y) + 0.00002 * Math.sin(y * X_PI)
    var theta = Math.atan2(y, x) + 0.000003 * Math.cos(x * X_PI)
    var bd_lon = z * Math.cos(theta) + 0.0065
    var bd_lat = z * Math.sin(theta) + 0.006
    return {
        bd_lat: bd_lat,
        bd_lon: bd_lon
    }
}

// 百度地图坐标 转换到 火星坐标
export function bd_decrypt(bd_lon, bd_lat) {
    var X_PI = Math.Pi * 3000.0 / 180.0
    var x = bd_lon - 0.0065
    var y = bd_lat - 0.006
    var z = Math.sqrt(x * x + y * y) - 0.00002 * Math.sin(y * X_PI)
    var theta = Math.atan2(y, x) - 0.000003 * Math.cos(x * X_PI)
    var gg_lon = z * Math.cos(theta)
    var gg_lat = z * Math.sin(theta)
    return {
        gg_lon: gg_lon,
        gg_lat: gg_lat
    }
}

export function downloadFile(path) {
    var host = window.location.host | 'bike.weilaibike.cn'
    var url = 'https://' + host + '/' + path
    // console.log(url)
    var elForm = document.createElement('form')
    elForm.method = 'get'
    elForm.setAttribute('action', url)
    document.body.appendChild(elForm)
    elForm.submit()
    setTimeout(() => {
        elForm.remove()
    }, 2000)
}
